# API Reference

## Core

<!-- prettier-ignore -->
::: zarr_cm._core

## geo-proj

::: zarr_cm.geo_proj

## spatial

::: zarr_cm.spatial

## multiscales

::: zarr_cm.multiscales

## license

::: zarr_cm.license

## uom

::: zarr_cm.uom
